Index: content/browser/media/capture/video_capture_oracle.h |
diff --git a/content/browser/media/capture/video_capture_oracle.h b/content/browser/media/capture/video_capture_oracle.h |
index 5bb1dd0083a309bb905ca47a8ce0a1329044adc1..db8ae41f65118bdc43bf5a5ae4cb08baef853fb6 100644 |
--- a/content/browser/media/capture/video_capture_oracle.h |
+++ b/content/browser/media/capture/video_capture_oracle.h |
@@ -85,8 +85,11 @@ class CONTENT_EXPORT VideoCaptureOracle { |
// returned false. |
base::TimeDelta duration_of_next_frame_; |
- // Stores the frame number from the last delivered frame. |
- int last_delivered_frame_number_; |
+ // Stores the frame number from the last successfully delivered frame. |
+ int last_successfully_delivered_frame_number_; |
+ |
+ // Stores the number of pending frame captures. |
+ int num_frames_pending_; |
// These track present/paint history and propose whether to sample each event |
// for capture. |smoothing_sampler_| uses a "works for all" heuristic, while |